# Welcome to flowsy
> A simple way to get track recommendations for any playlist in the **Spotify Million Playlist Dataset**.


**IMPORTANT :** You can **not** use flowsy to get recommendations for your individual playlist. Instead, it can be used to get recommendations for playlists that are in the **Spotify Million Playlist Dataset**. That's why you will need to download the dataset (or only part of it) in order to work with this library!

## Install

`pip install flowsy`

## How to use

Let's start of by converting the dataset into a proper format by using the **pre** module.

The converted **Pandas Dataframe** will not only be saved to **path_save**, but also returned, so you can do some further work instantly.

```python
path_base = 'D:\...\...\spotify_million_playlist_dataset\data'
path_save = 'D:\...\...'
```

```python
df_tracks = convert_playlists_x_tracks(path_base, path_save, n_playlists=1000)
```

In order to get recommendations later on, you will need another model, so you will also need another dataframe to train on.

```python
df_artists = convert_playlists_x_artists(path_base, path_save, n_playlists=1000)
```

Now you can use the **train** module to train your models.

```python
playlist_learner = train(dataframe=df_tracks, item_name='track_uri')
```


<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: left;">
      <th>epoch</th>
      <th>train_loss</th>
      <th>valid_loss</th>
      <th>time</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td>0</td>
      <td>0.006255</td>
      <td>0.006049</td>
      <td>00:20</td>
    </tr>
  </tbody>
</table>


```python
artist_learner = train(dataframe=df_artists, item_name='artist_uri')
```


<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: left;">
      <th>epoch</th>
      <th>train_loss</th>
      <th>valid_loss</th>
      <th>time</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td>0</td>
      <td>0.003167</td>
      <td>0.003156</td>
      <td>00:10</td>
    </tr>
  </tbody>
</table>


If you have successfully trained your models, you can now use the **core** module of flowsy in order to get recommendations!

First of all, we need to create an instance of the **Recommender** class:

```python
rec = Recommender(p_learn=playlist_learner, a_learn=artist_learner, playlists=df_tracks)
```

Then you can use the **recommend** method to get recommendations for any playlist that your model has been trained on:

```python
rankings = rec.recommend(pid=255)
rankings
```




    ['spotify:track:665Jxlgi1HamPKbW1vwzx4',
     'spotify:track:3m1RVYdn4DAyLdnDMCvS4Q',
     'spotify:track:3zByVQLvdXUaDTubfWkpCk',
     'spotify:track:2dAzuxEnwjHmYN1K5bAZDC',
     'spotify:track:54b8qPFqYqIndfdxiLApea',
     'spotify:track:7vRriwrloYVaoAe3a9wJHe',
     'spotify:track:0eidOawKujRH6fNpqHpCMu',
     'spotify:track:0p1BcEcYVO3uk4KDf3gzkY',
     'spotify:track:45eF0AQGCTgkUJ3FoIYrbe',
     'spotify:track:6iD3tf5OLLlK3ertp8XENc',
     'spotify:track:0U9TKK9GYryei6Vn45TEdH',
     'spotify:track:0qt5f5EL92o8Snzopsv0en',
     'spotify:track:2Nz6aF1umHh5Et6I5H581L',
     'spotify:track:7lJbTVbDEMa3w7NFamrwdq',
     'spotify:track:7p2aGxnxFYf6VLQPEYirPO',
     'spotify:track:4sscDOZCkbLSlDqcCgUJnX',
     'spotify:track:73q3FpQVXWk5eSUnyo83E4',
     'spotify:track:0iTpQYzJnYgh7kIxyq8A2O',
     'spotify:track:3Izr0NYJm5Hp4hwCgtZbDJ',
     'spotify:track:5MoYcbJbvZBgL82kYGY9yh',
     'spotify:track:02B7Gcfc6lXcuDnoZZZjhE',
     'spotify:track:25tjqTcyrBqt6IHAbUJCYW',
     'spotify:track:6XuwiHxoUmeL8CXkF82TI1',
     'spotify:track:78RbGe8Jtv55s1g6lh08uA',
     'spotify:track:3G2xKMcrJAjaeKx7qwHcxe',
     'spotify:track:6F4jYuSqnh9btApLxYr8kJ',
     'spotify:track:2W5n1X9ZIJEXCdVAwcvlAr',
     'spotify:track:06b3VaFsqYqbvQj1zFV5KM',
     'spotify:track:5Fm0370X5xpSsDy2AL0Zra',
     'spotify:track:6yrzVz6WjF4Whhj1dxIdAk',
     'spotify:track:0jHRla4jXwIi7ZcdaIj5o8',
     'spotify:track:5sp9fsQwYIXweVTxI7dRmM',
     'spotify:track:7nWC1XQv8bRMpVYuh5Bexj',
     'spotify:track:6dHrWj35HXTGvlCasE5VAA',
     'spotify:track:7Ewumzq8MHlC6OwNhBybGl',
     'spotify:track:5GCrBPWKpgH4H3bLLnvWm7',
     'spotify:track:5O06nbk5wDRr1WR3Tyo0Af',
     'spotify:track:30OHypsTSIxl3NoxakZtbx',
     'spotify:track:60lwJa695S26FsYbhCVFVa',
     'spotify:track:0IG0bhR18uNnfSa6nS0r0h',
     'spotify:track:2BpFudymbytL7gSQZNX83W',
     'spotify:track:6Mx7qe3gspQ8OKV3ULfiA0',
     'spotify:track:4MUNZkVe0VfomuSgY1EJun',
     'spotify:track:5pvVAwQbuFoR7LkcicrKnk',
     'spotify:track:2LZwKxTPZLBCYjUhlogMZl',
     'spotify:track:0hHdI7G32eAqxUbqRmltQp',
     'spotify:track:3WRQUvzRvBDr4AxMWhXc5E',
     'spotify:track:2P7O90JwqbBlsJI26miqNa',
     'spotify:track:0vYIpioP94c4gwxOyopklE',
     'spotify:track:1UAQHOnuhuGpF2iBCMXnTu',
     'spotify:track:4Ft7PYNG9LYzDWNeKqdkdz',
     'spotify:track:3E2Zh20GDCR9B1EYjfXWyv',
     'spotify:track:5ffwgrvw4tVlhFcI8efviN',
     'spotify:track:0iqvAEJMHQYUHGL9VLDQv8',
     'spotify:track:5nic9nCCfm5OP9KLrlejCd',
     'spotify:track:5MXTJktozOCF1KInWzVH5B',
     'spotify:track:7i082IMKU0FWcA7GzZtCzZ',
     'spotify:track:18pjREva50ELsn8QKviHvU',
     'spotify:track:0t6VDQI1X5KtfO0X3mcPlj',
     'spotify:track:3e9LhXat03hFvmS7YegDjd',
     'spotify:track:1bdSt7626m8iEOyPR33Up9',
     'spotify:track:49yo9G16eljLYk0ruT0jMf',
     'spotify:track:4VySpxhRGy32u5zPCprzDn',
     'spotify:track:6DZMD3ksHu5JutUzlHZtYY',
     'spotify:track:6p6xjPPAOpzmXCR4dfJJSj',
     'spotify:track:0udUoySNjmgtQc5OIwHHxn',
     'spotify:track:1bl3MTHuXMweBGdeuHUl3V',
     'spotify:track:36uzr8rOU8YKbbIkoe1DD7',
     'spotify:track:6KCiwJ61w9rsDOg5t1RRsQ',
     'spotify:track:3BkLpheTPPxLrAvi0dHId8',
     'spotify:track:0lFrqu4LpZDtjfiOdASyu1',
     'spotify:track:2GHNZvjA57wLRl4FVk0MhS',
     'spotify:track:7kksuEjvommE2D7QJvyJma',
     'spotify:track:70jtjJHtVBPuxllGPCWxnX',
     'spotify:track:0OwhEqx9AoECkHrHjE7phU',
     'spotify:track:5Du9saCXYuRkHcj3CA6Her',
     'spotify:track:0Po9oxXGsDXDnfNngwR28c',
     'spotify:track:71dRXDFvEPYv8iRh8qxc7a',
     'spotify:track:3nSvgsmfyfsY5nhZFJ75ms',
     'spotify:track:6owsExK6Rz6pX0VFtQDznp',
     'spotify:track:0yNwiO2VD2vakcfHZ1NI33',
     'spotify:track:2Arw3BvOzm5ljO3IpYX28D',
     'spotify:track:6VY8zV9nGLRIVaM5G3sKpw',
     'spotify:track:4rXFmHYKsoJc7vcpc90llL',
     'spotify:track:10McjLEshIntz70hO2Jz50',
     'spotify:track:3XRPkOVq4vGS7g9CRQwzVC',
     'spotify:track:32OlwWuMpZ6b0aN2RZOeMS',
     'spotify:track:6buKmjgqX7MruMP8nruBbJ',
     'spotify:track:5JkCyeCL0S3UqzlibpeDdb',
     'spotify:track:77GZxme1GMNbbooEH8nHNX',
     'spotify:track:1onytNPylVczmCf0IW4Jv6',
     'spotify:track:4ZUIfD1hkwOjHtBd2iLA3u',
     'spotify:track:38hoUe0bZq5OYdixN0Ozki',
     'spotify:track:3C57ewlHARCVqeH3KiYkma',
     'spotify:track:62U57s3x5TN6Awljt07i8D',
     'spotify:track:6RcQOut9fWL6FSqeIr5M1r',
     'spotify:track:4Yf5bqU3NK4kNOypcrLYwU',
     'spotify:track:5eFxwmqKrHpSQDOEIFYlgY',
     'spotify:track:1b7vg5T9YKR3NNqXfBYRF7',
     'spotify:track:0arNrzPygksLY2pEbRgBjw',
     'spotify:track:6GIrIt2M39wEGwjCQjGChX',
     'spotify:track:1UkMAtLU8NxsddE7j4zXGO',
     'spotify:track:49qmdPALsDMBHR1MfqIfOy',
     'spotify:track:40bm28QcJT5My540ymSQ2y',
     'spotify:track:305WCRhhS10XUcH6AEwZk6',
     'spotify:track:5oQcOu1omDykbIPSdSQQNJ',
     'spotify:track:1zusIxNqJu8i4g6P6hJ2Qa',
     'spotify:track:3JxefpUPB9vmI2ZO5MMYZA',
     'spotify:track:1TfqLAPs4K3s2rJMoCokcS',
     'spotify:track:7w87IxuO7BDcJ3YUqCyMTT',
     'spotify:track:6LTaVrJRoFtSw2xFBpARs3',
     'spotify:track:0jqK7sGTLsHPkQrrcrGuKD',
     'spotify:track:6ndmKwWqMozN2tcZqzCX4K',
     'spotify:track:6m59VvDUi0UQsB2eZ9wVbH',
     'spotify:track:0pSBuHjILhNEo55xK1zrRt',
     'spotify:track:3Nl6eD5Jz6TLESdBx1Mpjo',
     'spotify:track:3lO38SiB2WAQRqTAHN7WTC',
     'spotify:track:6f3Kn4QtwZPU2IvwwDSbLF',
     'spotify:track:085JBuPwP0YbPgc2t6Lscc',
     'spotify:track:7jDOx9VTvxq0S9z8RjQ7lv',
     'spotify:track:4F1GNyFyinJH9W50pJO0RR',
     'spotify:track:48EPGcauDd6riOMLxEPM3I',
     'spotify:track:0xfdG2n1zrephk64xqQC1q',
     'spotify:track:5Ev3sAE6AN0baPJKe3vcy1',
     'spotify:track:64AFKcZzIq3cMVpAPM9DYB',
     'spotify:track:3b0BEtQ7qAWGJ1ueivzuAU',
     'spotify:track:3SEYycG24ujPRnGad41w2E',
     'spotify:track:7EYWVZwt5x3N9lAUBLFwr2',
     'spotify:track:1BPPnDSpYfVGx1fYWyAWvz',
     'spotify:track:0au5u99zsQ6yunHfywDX8a',
     'spotify:track:5QSYWruQQ7kBCHScI4xJ9g',
     'spotify:track:04CpKcl1ItOezCVVkIL3E4',
     'spotify:track:7nnIbg5MvyIceuuRzwFZjk',
     'spotify:track:6Vhe8Hg51pzixWnsX4X86z',
     'spotify:track:4G3lJ7BTMugaj5Sqp7fnGs',
     'spotify:track:2wMBKl2M7X20iHrbDcDp4D',
     'spotify:track:2vNY0WQo5xtwQPYnuPlwEB',
     'spotify:track:4u5OD6BQNt2hztXYZINZNS',
     'spotify:track:1FneiT4MnWCOIDHUZkZsoO',
     'spotify:track:2stnUIKHtPrG5Hde3wqQc2',
     'spotify:track:068FF1fJiNCyeYkQvDTntw',
     'spotify:track:321jLsfufuG8Ot8GsYffdm',
     'spotify:track:345RHjiEdIVedsxtiwGG7t',
     'spotify:track:6mUjZMRxxE4kYnYnXrdYm4',
     'spotify:track:1nftNKx6O4GhgImhTyTs6B',
     'spotify:track:68TUAeelb7c3wzfMNPOjmG',
     'spotify:track:5y8qfDDccV2kEn4roGPter',
     'spotify:track:2CKuXVftZK7fRpUsrFvY91',
     'spotify:track:66fjBB43iramIyjHulpkMN',
     'spotify:track:1oj4KLsbYhvfHFnhdb3twP',
     'spotify:track:35ihWLSURZaIbJA1iLJgAP',
     'spotify:track:1DdYWvSA2lJbYqzpm3moC6',
     'spotify:track:6QbbxQtijqLfUV90Vlm1Xh',
     'spotify:track:6sio3UGjtYpYgg9Ez3Q6os',
     'spotify:track:5t0izTLPeWYLiIfHPJbORJ',
     'spotify:track:0i3QayolUcd7kAm5AyRp19',
     'spotify:track:37sWianweYMt42ZoSABn6y',
     'spotify:track:6v4zAuJTlszNdKrbbnEFu8',
     'spotify:track:04FwOgIovwG5ItELDLfPfj',
     'spotify:track:3BGbqEDio3ocx1v4egIYr6',
     'spotify:track:5RtIFveFctGcvO1J9wVStV',
     'spotify:track:5CLnJjfZjXigfPk8iKEPBE',
     'spotify:track:4SKlwyLMGQdzul5S5TvCh5',
     'spotify:track:33iv3wnGMrrDugd7GBso1z',
     'spotify:track:5hcer4MP5GeHqtSjDYx5AC',
     'spotify:track:2hdhm6piUJnmKXmEmskXCg',
     'spotify:track:05wIrZSwuaVWhcv5FfqeH0',
     'spotify:track:3rfDfPjgHDQ1BUaSHr9xoI',
     'spotify:track:2FfZg072w8RoxlMOR7M4CT',
     'spotify:track:1Jaah2tmN9Hv81A87KZ1MU',
     'spotify:track:2HF2D2b2m66EK6fwGcHIor',
     'spotify:track:3Z9PJ6xiEGmcqo2hESEB5n',
     'spotify:track:2skmOCFU64Bg7Ytkgwliwe',
     'spotify:track:3cfOd4CMv2snFaKAnMdnvK',
     'spotify:track:2sxEZAXXUG0eTFZpsCDKR6',
     'spotify:track:2M9ro2krNb7nr7HSprkEgo',
     'spotify:track:4bJ7tMJqfYmkKgCYzaaG4B',
     'spotify:track:6S0IRhCK4P0llKnIjivfGd',
     'spotify:track:2VvfTbJWcguP88dvnpH7hl',
     'spotify:track:6y6TLb3rwDRxP5I3qK0Py9',
     'spotify:track:6ZQgLj68uDyiNdeuIsLkjq',
     'spotify:track:0za4yuB3UmITV2L9QMwlV0',
     'spotify:track:4bhoQCNYx5TjINvtSMiaAb',
     'spotify:track:3OIKgKNUt87GHz8OmmHZop',
     'spotify:track:5UaReL5xWZIGLs5VBqouq9',
     'spotify:track:42RxuQMiI908vPbh3djeOm',
     'spotify:track:6Etu0fN4yllmZ5oTxKd0pt',
     'spotify:track:3DgEeHFWREJ0TK3RiPjWwQ',
     'spotify:track:3EEzQDCP8jRl2pEt9eDKMO',
     'spotify:track:5QS9GYw1lZtIIlfnCqNvgX',
     'spotify:track:1YI4b8Wy9CdGiacUy54RIQ',
     'spotify:track:0ZZ9kLRomzTbnmtzcE1dO2',
     'spotify:track:4yfEK7mOkvUwTrvKCeyOTf',
     'spotify:track:14Nn7fmweYvSJ7SnDIsfEH',
     'spotify:track:7tUUZ74ZhKN8B1IiMREYlO',
     'spotify:track:53H0Xxf7BhAmbSprGkJL5m',
     'spotify:track:0tJCX9QKpIr9YPZzRuXWOe',
     'spotify:track:1qyRvPjbQZbPPwVGtApQ7P',
     'spotify:track:2TcWNtN8aiBHAS4DWVvpPb',
     'spotify:track:6pvlXRo37T9hps7z5dEp0U',
     'spotify:track:5iXuX70Sxp6sKdumBcQQW7',
     'spotify:track:4fkAWGCbxNizyNwsHlrajH',
     'spotify:track:6JH2Z9YixSoQTgIoxx4w3P',
     'spotify:track:2rs0JKFm7CjovNlfYI62cv',
     'spotify:track:3YQacpdl0a7j1KbKDEUcYh',
     'spotify:track:5T4j3Uv33fQO7tsR2lMl4y',
     'spotify:track:4bJbSERtCqK9D6DRUPMmMh',
     'spotify:track:1SHjeFXej7qNXpHFAuv9zL',
     'spotify:track:57MbOuT7s2ES3IW9KuZQzI',
     'spotify:track:1Yw6ViCo3tuufI0Hg4mzSU',
     'spotify:track:4ztR83ZgTdg8H9xypnsQfS',
     'spotify:track:5nt7eRlOOJhrsBSrHWiY4I',
     'spotify:track:4ewYje7A0JyY6GXpenAk4z',
     'spotify:track:42qRkSY47AqYbOV9OqPyV2',
     'spotify:track:1i8FJaKwn3OjZCqGMUnoKG',
     'spotify:track:4bYqnqT92z9bi50a2tRsjj',
     'spotify:track:6qbZpR7vyyU5EDJ0a8dX8k',
     'spotify:track:26nKLWXp4l91qxdrOlCEP9',
     'spotify:track:4y6oj1cDAyFRlZdqLkOrOr',
     'spotify:track:74CRWolE5ys9xf30JTI3H2',
     'spotify:track:1pXAZZbOzEjsg4h3aOo5iD',
     'spotify:track:6TzfRFDXjpI5IeKfWC9NTU',
     'spotify:track:4SZM1j8TEdxdFNWnBdV52x',
     'spotify:track:5DEdP7MrcgdjXWGHWAeK5I',
     'spotify:track:36Q7Lexy7r0g8W7gz5o5p7',
     'spotify:track:4bDHr5yOmdI2nmbWvBpPS2',
     'spotify:track:5YzckYO7G171MHg1UqkxJY',
     'spotify:track:5clz8BOBulxx7q2yHxqOCk',
     'spotify:track:5DJb6A4bRgCAMaikSEzdJH',
     'spotify:track:0Puj4YlTm6xNzDDADXHMI9',
     'spotify:track:3JtdmGmWOoZ4j37gj9Uzmp',
     'spotify:track:41X9To0bQ4fpoSRri4NHiI',
     'spotify:track:4dTVgHZFPlaq9nPbLVVLSG',
     'spotify:track:5Gt1nWO7EVk5oW5cagcqbS',
     'spotify:track:32I9MdnqhFLCnAwA2wUnTz',
     'spotify:track:0xOeB16JDbBJBJKSdHbElT',
     'spotify:track:6ptsvwWMeB1r9VrKY3j4YM',
     'spotify:track:4tPFEWRuNQhibDQSGB2PVE',
     'spotify:track:68rdZO4AcPakdi2zaS7kPI',
     'spotify:track:1Co1RNm1i1RL9v1VeShNO3',
     'spotify:track:2S6yBUXa5KddBV0CqBkcP1',
     'spotify:track:6nxHMqTNKWlQnx5AFxz1iX',
     'spotify:track:5PYbfWPUpAYf6tMBXhLM5u',
     'spotify:track:6CryGd6wVcpWf5J5qH7cvZ',
     'spotify:track:6egzrRrypKd9iitBMt2Uwq',
     'spotify:track:3glqlA5qY3bbo8UaUDGPnw',
     'spotify:track:7MHRGUwn2J9TyRFOGFOX40',
     'spotify:track:5aDcKVJ7YTgAxyT27S0YVb',
     'spotify:track:7jWIolCo1nHYaAmOvFH0Lo',
     'spotify:track:2K6Zk9lKbzAGjjfZbg59Ia',
     'spotify:track:24FmdHoCr2jZGE6Z6dZbJT',
     'spotify:track:0PyxraBvpi88QA4qiX2K5j',
     'spotify:track:0GjQ1BRniIHyRJ8ATfpCBx',
     'spotify:track:4WIlSfQq77VOALZIcXtyQ9',
     'spotify:track:1JO1xLtVc8mWhIoE3YaCL0',
     'spotify:track:1YT65r02sCsJboh4yb2s8X',
     'spotify:track:2DvonT751gQIRikzKDDGId',
     'spotify:track:4BAWCedKFfdwxPFmFv4DMG',
     'spotify:track:44p8HtTtPp81ESuZP1aix5',
     'spotify:track:5CI2tcJMXXl4BinAk3DI1K',
     'spotify:track:16PiUy0P2mmJroyHbuGCXB',
     'spotify:track:3FECBXr4grUJ57bVWvV7b7',
     'spotify:track:6clYXXfpfNZ8MGcBSYr64b',
     'spotify:track:6FJfXr849kkY4K5fgAKg4R',
     'spotify:track:066nVSMAHBa3UxtE1m4c2j',
     'spotify:track:7IEcPKS3Fkd9DgajXPpbSY',
     'spotify:track:6AusPFTFwk5iuqF3ekn7gu',
     'spotify:track:7w0chcuNV2QYryLRRXSuyh',
     'spotify:track:1qP7GQv65XvQBQoKMadJ64',
     'spotify:track:54QsQ3wVu3BevTQm7udOmF',
     'spotify:track:6TlRNJaezOdzdECnQeRuMM',
     'spotify:track:4v6jydWBTAIqnyPVNyOAdc',
     'spotify:track:7KgneETGBycWbmIfK2fagH',
     'spotify:track:0FnscCdhOOin94zzmifJ3L',
     'spotify:track:2WDlSgb4q9ETwyZEBUFM8s',
     'spotify:track:4riiAdWWB9qw9cJkfSWQfe',
     'spotify:track:18sytW2s53Of6NVudQyUlH',
     'spotify:track:1OK4hVcucqYKMU9Ipb3dtx',
     'spotify:track:24lF0of2nbQlTYDU8i6glX',
     'spotify:track:0KgbwF3wEBvPWPwwTLo9iR',
     'spotify:track:1Ktsil4bC4hYRWlqMG4qK3',
     'spotify:track:0ks5sXa1iEMvtVbYOsfiNq',
     'spotify:track:3h5IJ0EzVpkiaoL174GC3M',
     'spotify:track:7f0jXNMu2xjQUtmKMuWhGA',
     'spotify:track:4htbAEZWr53J08x3dUv00W',
     'spotify:track:4HE7hVjthyaSQekgDrLSRj',
     'spotify:track:3kJXrEVUCdPQ3e4e5k9OHC',
     'spotify:track:0j55p8YRAPG8yajtNyjt6A',
     'spotify:track:6gk2V87atn7XaaAltdYsKd',
     'spotify:track:1kPBHRXyXdrtYfUfeRwBko',
     'spotify:track:53oWwSxPuyH2cjYKXH8fgO',
     'spotify:track:5MM6AKQW2WZkexW6K6TdBq',
     'spotify:track:42rFOQqHmXf9IkdwVqkooK',
     'spotify:track:0eX0IL0sLmEQQAhojl357S',
     'spotify:track:1MQCTOWVfy4PcuBXkBsHVB',
     'spotify:track:5HEjbOF2miSnhwJX41mXZJ',
     'spotify:track:4SWkHr15YgPdLG25gJpJiX',
     'spotify:track:7KEguG3CDoestm50v6XET5',
     'spotify:track:5dWfl2PBpKHpBVdz95wxK1',
     'spotify:track:2He3NOyqtLNE3RQPpeDdSb',
     'spotify:track:0RZXNlGPvfMo54fd6uCvAT',
     'spotify:track:0YYhDyUqEGdO6mEUYQvZMw',
     'spotify:track:6wpz7aQOAk2plmGYrSr61H',
     'spotify:track:0jyT0KDZEVQGg8YJZrWvcm',
     'spotify:track:7Jb5kszpP3bbm9niXxvHtk',
     'spotify:track:6QEvc1Xriqvn70EG2VrDy3',
     'spotify:track:6Y8RnWtEAF6jSMNtuzJmnj',
     'spotify:track:1tfjYWYkJeZPjaSsF4YdH4',
     'spotify:track:2zOs2Dck8ilE2DqpjZVdD2',
     'spotify:track:4E5P1XyAFtrjpiIxkydly4',
     'spotify:track:3cNjgVBKTJ1SvKhunrCdVy',
     'spotify:track:5G36Ny8Kkw0xyofPJXA55h',
     'spotify:track:0Q3SC6kEhxYagDP3bFe5K9',
     'spotify:track:3Z3nWmHo9Dm3bbHiZcZraD',
     'spotify:track:4y5tv0m1pUQMAt4AV7xjta',
     'spotify:track:0obMS2ZOAeBBWNM8slSy9D',
     'spotify:track:0QqHsY5aaUoZdoBF4ebe15',
     'spotify:track:4n3cSoUdQdM3wglBkfLP8I',
     'spotify:track:7cV0xhXZOPhdlBUODvCrDZ',
     'spotify:track:2UowIqvnh5R2gSQuiVTJD4',
     'spotify:track:7jSxbGawkpGL6ySOvVHoaf',
     'spotify:track:0v01kH5JCzTx6wWjIRH5H2',
     'spotify:track:0ieAoqb0vVSAA4tZQsVeBf',
     'spotify:track:2jPLyQJHRJnFu3Dst8bduw',
     'spotify:track:4ACxa9buEUnOdYEoPcnMpi',
     'spotify:track:2NSFg6KZjXOXLOZ3ayZFbV',
     'spotify:track:4s0QpaeB5a3C9cxNGqPXxk',
     'spotify:track:0eZBeB2xFIS65jQHerispi',
     'spotify:track:1P3MmQNUtdleRmaAElZFA1',
     'spotify:track:1LszjjoVwDDZcWUQbzeDLG',
     'spotify:track:6QbcLktLNe7eYqh8TjZeCd',
     'spotify:track:0hkR93a0LriV2CQUhSXw3h',
     'spotify:track:2CVPwqvMufcF3a475EhZQw',
     'spotify:track:3YVxSPmoOYnEJzlO2gRdIk',
     'spotify:track:1MD4tX2g5hx0D2WQ6JsC2m',
     'spotify:track:2AUJzPtP7sFEnIK0zRWOR4',
     'spotify:track:0xMEF2WiqKWTIG7Krjungw',
     'spotify:track:41FC5kULrM5rbxN7lOuy25',
     'spotify:track:4jKq1e80xAYixkIwt6YyV1',
     'spotify:track:05KeRMxuutPAe5JOVlzZi3',
     'spotify:track:6ysQEIlw4DYNpkzCx0TvOs',
     'spotify:track:3mGW6kG5UZLLDb1vVxRnl4',
     'spotify:track:3eEQNLhV6KLOcVz4BrbH9l',
     'spotify:track:550rQQCGkrTzvp4SfpOPzx',
     'spotify:track:2v6r8OXPY1exSpSMROIwr1',
     'spotify:track:7sXg1VmdnM1Ho3aJPya5SC',
     'spotify:track:5QrrV2BYDmrdA4SRxPNewJ',
     'spotify:track:2B7isQhlpOFWhnjYosAZs6',
     'spotify:track:0koHJqcpJ5x9M7RkrUVLyt',
     'spotify:track:4GvSUxUVUClNo3QM7XvsZV',
     'spotify:track:5oIkpctyGGFGCUSoialWbS',
     'spotify:track:5CMnZOiqyYBF4ed9quStA3',
     'spotify:track:3lMBtTGDs2y8kLNAKeVnkX',
     'spotify:track:7hzY0LHz8KdEr1PowHhbdu',
     'spotify:track:3cwDSDzTiWr5H5xMQhQ6Mx',
     'spotify:track:2nUqoEvPh5fCXCq3CtDGM4',
     'spotify:track:269OfNY9Je1QWaDnu31KKp',
     'spotify:track:54bxxfdPQ5jsWXMF9JQ0eR',
     'spotify:track:4VZDv8sASBS8UruUBGTFdk',
     'spotify:track:79DF4VeuuI0Y7NOrimSmR5',
     'spotify:track:5TdCUrQdTWZoTSAZH7Pfup',
     'spotify:track:7gUtrUENhHW0GMnT2h0W9f',
     'spotify:track:1QpMNpzkMxchOeYOn9RbNJ',
     'spotify:track:7l0Lr7Tl4Gt8hQj4v3rwtf',
     'spotify:track:2bwSCIuNtVrQPVddCi8sOW',
     'spotify:track:4UQLQJu3DNvVkMVglwElU2',
     'spotify:track:0DLcjcjvUywWkPYseSdg7J',
     'spotify:track:5KY7zgFeH2GWoL1zP9mME6',
     'spotify:track:1I8956VUImfafRIuccR9Cq',
     'spotify:track:3Zat6hZbvo13Va3kMHAKJx',
     'spotify:track:6OSyCAmXT4Gkd3OQ2aPOaF',
     'spotify:track:1boMeuYiWu7Lq8NSFMCvsw',
     'spotify:track:6EOdY7I7Xm1vPP1cyaGbWZ',
     'spotify:track:5B5tNyIXRMsIKQqKoSzpt0',
     'spotify:track:4Z3qm2aWGTJuJKnv3EWwyD',
     'spotify:track:0PT7nlpo11hYYyfnBgtilT',
     'spotify:track:25FTMokYEbEWHEdss5JLZS',
     'spotify:track:2iO18Hn7raYltnUmpJXlun',
     'spotify:track:2e2jSI2Bqb5ju6S1UdFsrr',
     'spotify:track:682cnKvTcXg59UvQUic4t2',
     'spotify:track:6225vlQNgif1W5dE5KN6Y6',
     'spotify:track:3eUlmjvp6SPOshc4JsAAfX',
     'spotify:track:4CsDlMtoESHZCMcjuoZInd',
     'spotify:track:0eKSlV7HjwHH9KI5SpGrKH',
     'spotify:track:2YePYsIAjvrtqL8HQ9pI3b',
     'spotify:track:6TJaLcFheD9XjAvhltrQnC',
     'spotify:track:0kIHfcHGFGm5xb0dSlKEdp',
     'spotify:track:1lp1YyncJKAabaSuP3vvuf',
     'spotify:track:4w9PCIop63BgFMXiEv7Emg',
     'spotify:track:4yt05iEquMZ4r9Q3hoZMBq',
     'spotify:track:0QXaOq4DrPkX7cJsXhERrE',
     'spotify:track:5lfnYyADlTmXNrhAG4eqlS',
     'spotify:track:3F274sv7NCtXfu88YEEhXd',
     'spotify:track:6HS5QOvhd4w3XqJMDaEWcv',
     'spotify:track:3gH77FPZuIqEMInBp89U2I',
     'spotify:track:6WGaVdhY8uMWMgxiKpdLVy',
     'spotify:track:5jbMLzeG5vlZZencTaUm9m',
     'spotify:track:0Xg68XXMRWzKQvD5S6BFvI',
     'spotify:track:6ZT3coOj97F6CVvruPtnox',
     'spotify:track:0ga8SPC1uPdqkzPUns5VVS',
     'spotify:track:4keTqSG4zdCmsUsK9KXv9z',
     'spotify:track:7qOBjxnF5qUfXc77zUaDFI',
     'spotify:track:5MGeW5mHnqeJiM0NPBbkEZ',
     'spotify:track:1tTZM7LUDkxcykOVVIGW4W',
     'spotify:track:0SfMgcTwpJCSKN0pA0nNCN',
     'spotify:track:09UsSyxME0KR5xmIQClUVu',
     'spotify:track:4gqbBxOfJpFdXJMAfyKXlq',
     'spotify:track:6UD4ZiV5GNEqUMLi5KJv7z',
     'spotify:track:58zsLZPvfflaiIbNWoA22O',
     'spotify:track:6qWG7dpOSs5dfgJ7d35am5',
     'spotify:track:2U8NXPTXZWG2O0ye2sYRiH',
     'spotify:track:2WmXaY7nVgIS7ozqJJHfjC',
     'spotify:track:1QukgQhqTVgT8VFiG6Vxgb',
     'spotify:track:6BC5qv70s01qQpFyKSsuLV',
     'spotify:track:4x4bz6m6oYvRPxNU4HRQHZ',
     'spotify:track:6bxqzkso7nAs38KiJXS128',
     'spotify:track:5YVYVuNA44FT2yVxEXOw3r',
     'spotify:track:5uMwuzrvG2377KmsOnEmcg',
     'spotify:track:3WeLxo3f1T6pjfj8Fexz9D',
     'spotify:track:60zAPpWPM1gZLl3ep9QmCd',
     'spotify:track:2oSLptm3VY9mVhxvCNKpfw',
     'spotify:track:3G7XYAwtxtoGK7fAm4IlD9',
     'spotify:track:0OwX5aROoW1Iip8FV51Efg',
     'spotify:track:3SJv9Gmnq6VXM9xNITfIw1',
     'spotify:track:1GQwZguBEt9mNIqXnPQTaW',
     'spotify:track:3V7394yfE7A1Vso3PqtWFD',
     'spotify:track:0xikWgPgYN9BEes0ieZ8Co',
     'spotify:track:0TNLaENR0mjJat58GJ7wOs',
     'spotify:track:0J3I49UdftZ6qSWZf6ItJs',
     'spotify:track:4t80TQHYdtzwnUGBQC4yL1',
     'spotify:track:7qzzZG2V9HCz58RxyX5n8n',
     'spotify:track:48J4hwHh4KJ5216fktYwWg',
     'spotify:track:4BtaPciwVOkH7eFC59i27G',
     'spotify:track:0iYwU4n6l1mrfyw9diGLEa',
     'spotify:track:2mp3sLUNQaJ025Lx5f4AAJ',
     'spotify:track:4xlhd0SpVU3JRULB3Q9s4L',
     'spotify:track:1nrv1lKg6R7aT4bPQkywZF',
     'spotify:track:1CvhKmrutTAta5awpJcFDn',
     'spotify:track:1LpjlPR8Gv52B04UQNLZAw',
     'spotify:track:5HVHYpNllysLkUEduWKqlg',
     'spotify:track:3cRi3XR81GltxQOgMfjNBA',
     'spotify:track:0Nu9WA8kEbBWEsay2s8Q0U',
     'spotify:track:2FSVDuHboKIY4MAV10wAIM',
     'spotify:track:2YFK8mpSIJfJZS5IsZ1cCc',
     'spotify:track:4NTn0Yo8hTGW5tbBANBzfh',
     'spotify:track:2ffh99UXcvaqSYALBz2x4J',
     'spotify:track:5LnslfFSyDEkBDIfK2s4m5',
     'spotify:track:1cZMpIV8p6PATxD32t7LZ1',
     'spotify:track:4k9EkhkFZY8Bk41Qi0Ob7P',
     'spotify:track:6zkK3JvLYHCxKUcBaEzc0W',
     'spotify:track:2v7EYRJaqHg29z1jnx59yI',
     'spotify:track:7M7eanIuxFd9IgaB8rAP7b',
     'spotify:track:1gVgkQFOKa8Wc1HYsJtPdH',
     'spotify:track:2374M0fQpWi3dLnB54qaLX',
     'spotify:track:2rIqbiRDXuiWxFHfLgzYRe',
     'spotify:track:6iF5JgF1GNUQwlnsgnMzUu',
     'spotify:track:6KT8BsrXfGn5SjhKBdL5rY',
     'spotify:track:4xtpy5lEYd3Feg17826h4d',
     'spotify:track:6LxcPUqx6noURdA5qc4BAT',
     'spotify:track:60wK3ylmnDG9MqbnMqbupZ',
     'spotify:track:3R33zdBoZmsBAOOYgiGZRI',
     'spotify:track:4ntsD33Pgsgk8rUyZLLiUV',
     'spotify:track:4ut3GECMptkuUIMiDQPN9i',
     'spotify:track:18y85RXNwPsaqTwKPfTqZI',
     'spotify:track:2rxfHBai4BOraDIIRgeMZI',
     'spotify:track:0lU0iji9AFomv0zxl5JB59',
     'spotify:track:1foCxQtxBweJtZmdxhEHVO',
     'spotify:track:1hEh8Hc9lBAFWUghHBsCel',
     'spotify:track:1rxwgnMAUAQH8lfkw6lnIX',
     'spotify:track:40yzbqcZiEIPOWcFVR5Qlr',
     'spotify:track:1V490lJLEZRPjDk9JGtcMN',
     'spotify:track:5uDASfU19gDxSjW8cnCaBp',
     'spotify:track:1vpIpYiTmfPHK69ME8wJ0k',
     'spotify:track:0RFCAbinDyaIklfLKfoatm',
     'spotify:track:3s5WerS0heEMyikkSgwUqJ',
     'spotify:track:1IAPmCI9x7yR2tglbShurL',
     'spotify:track:7LjIjnztu0pzLsSQO0wOha',
     'spotify:track:2NFYkgjUiiKgplnB7tgjoe',
     'spotify:track:4Shpyq2PAgkpO8vKTgqYoW',
     'spotify:track:73ZTWCuwudUVvvWipRnQnQ',
     'spotify:track:1P80uWtkwsMF7I3XH8wJSx',
     'spotify:track:0DgY053iwPDydoRymeGVZX',
     'spotify:track:4kK14radw0XfwxJDPt9tnP',
     'spotify:track:32yiDCLJUdqYoaDR46z9gD',
     'spotify:track:60EtAySYm0qBlPj3LSXil6',
     'spotify:track:2xSJiMxoZ9eiqsWhfrdYjs',
     'spotify:track:2oii9PUTn2UkFD97W3ge4x',
     'spotify:track:0cNJ3huiV99wvUN1tmQLTL',
     'spotify:track:47muNlVTjDtQfyUqDaiFlN',
     'spotify:track:6DVu6RZWnPrI8OLwrJXReo',
     'spotify:track:5dzV75f9qVXVvdXLTqIG4L',
     'spotify:track:3bELVNyQDvjRqJiMiFoohe',
     'spotify:track:4CisE8n8bzLRnCrL9Oyugg',
     'spotify:track:6PTvs4BA2uYE8mKvOyFMPN',
     'spotify:track:5kKVGP5CQNuGiFN30cFZVw',
     'spotify:track:4raUe9c8X1PYDhMnbjssS3',
     'spotify:track:2i37Y95xkPhHtoYBywVBUm',
     'spotify:track:63Q9hAFTga7rqYRrAhwIyR',
     'spotify:track:6o3s08kk2fQI37vxGZDrJ1',
     'spotify:track:5JuA3wlm0kn7IHfbeHV0i6',
     'spotify:track:6fTdcGsjxlAD9PSkoPaLMX',
     'spotify:track:4F4hKCEgevJgNq27pYz0Mk',
     'spotify:track:6ctbCIikHbC6tSOL1rewQX',
     'spotify:track:0ez5z16E2mTpqlwr9kxxoD',
     'spotify:track:2XFak3Sx0XCoXJpPt5TeeR',
     'spotify:track:3MoJoDStgGIfFEGkRzUSEB',
     'spotify:track:2npStoMbQxG1LcIeF4PZrj',
     'spotify:track:4xXpuMj1agXiicS5jZovFE',
     'spotify:track:1GaYqv2NMMlVbG3ewJQ4A6',
     'spotify:track:0lUt61v9PK6Qrl0GjkTXAw',
     'spotify:track:2i1RgMi6dTpTEPEYEceDs4',
     'spotify:track:3otZLoLcx2d74hx8RaHXh6',
     'spotify:track:0pn6qyOJYNwP9nhGg3L7dV',
     'spotify:track:3lGL219tz1Cjy5Zeno5T7m',
     'spotify:track:2ytH5wDuqhgLTiDVYioteq',
     'spotify:track:1mSMwIW4ZK6DVl499FvDPv',
     'spotify:track:4tG0cdbL7v4pQ8RWOqLDHx',
     'spotify:track:05BDasfCA4TNR3HbMjSpgM',
     'spotify:track:2SIN2Xn0VSfhFPo5juyhnn',
     'spotify:track:13ZzTL4ycsFXZ9nxjPHIrM',
     'spotify:track:0w7XcNz84saf5p1nigc22t',
     'spotify:track:6aFvJSvmAuTuQSPZwK8rrN',
     'spotify:track:6ELFcF8Wke9n2y6iWWTZU7',
     'spotify:track:2gdmo3ULjoHN3iDsufbvPG',
     'spotify:track:5Nn2Dj7OQsGL6pgQ9iIzPp',
     'spotify:track:4zMP6aieSmWQNFdp3O4Owv',
     'spotify:track:44aHFtDMjOmUCVeOOsmQ7A',
     'spotify:track:1ptm2NAvNHnVtpDN51DLCJ',
     'spotify:track:0U0ldCRmgCqhVvD6ksG63j',
     'spotify:track:3fCULruC32uHpryWa2yKRI',
     'spotify:track:3be5ey9pSoqLBu6UNtoRCc',
     'spotify:track:1ZyMdpNyiw4VYsbmHFgzEp',
     'spotify:track:2OIlOS419OC0McH7i27Kat',
     'spotify:track:3Q45IUL9NICk5gL8kctLMO',
     'spotify:track:78Id7Rdh9fMmmFYuDZB0SN',
     'spotify:track:5zT5cMnMKoyruPj13TQXGx',
     'spotify:track:09WxJCWFMWAxTHBLLelpDS',
     'spotify:track:71A6V5dh5Y8ikhm6NGwZ7p',
     'spotify:track:3WWVDPjihd1VITBLF10nha',
     'spotify:track:2fos7qVkEFxPREMUUOnm3l',
     'spotify:track:0Ztn5JEuB4NwFwj4vVvd2c',
     'spotify:track:5adHHTqF2cbrsUf6crK8vl',
     'spotify:track:7xFIGogB0650amgZQnsVpI',
     'spotify:track:6OVsn2uURKTLIguCDxgNWS',
     'spotify:track:4BFMQ15vXr626UOoZL8bUI',
     'spotify:track:2d14mYTkxQF8XEAHhYkfRM',
     'spotify:track:57kozn0j4DL3toKrqKQY0U',
     'spotify:track:2VTQAjZr7FPoEJD2sNoH3o',
     'spotify:track:26T7C1NMXKE7hCWhKH2l0o',
     'spotify:track:51tlhldI8DI52dSkwveAeI',
     'spotify:track:4gXPGKRbGGbcSI8imJMkZJ',
     'spotify:track:2mUNPeRl81MwJpy40yqjED',
     'spotify:track:0M803XWBMwksKgd09qv6B7',
     'spotify:track:4dyx5SzxPPaD8xQIid5Wjj',
     'spotify:track:3ZYeIGWneqMC98Gu0Ely1C',
     'spotify:track:3X3FBv1Aid3AkVdCkgkpnF',
     'spotify:track:4pJt6B16mFRkmHfXUYmmrK',
     'spotify:track:1QEEqeFIZktqIpPI4jSVSF',
     'spotify:track:3z31bGbh9zThTEXPQqErif',
     'spotify:track:01MO5Ib9mCG7srUhZl52BA',
     'spotify:track:6vXHaWpqkbuvzIDvR3LnKd',
     'spotify:track:4PFQ4EQBtJUp2jQjpmYkVA',
     'spotify:track:4L2K7JKseFCBoHMZEAszW0',
     'spotify:track:1almCHdsfikRPfVB9VrEdT',
     'spotify:track:6zWpqo98M9Ai6TK3qmm55o',
     'spotify:track:67ncKGqScuJdNUN6bTqclA',
     'spotify:track:61iyAeMVUNu7vIVqedsBFB',
     'spotify:track:5ngpjmLmY4zqbzGMxGCdsm',
     'spotify:track:4MGOIWgrzKBzFGBDwn39yu',
     'spotify:track:0sQdzJAChz97Ea2Zg2Yx7Z',
     'spotify:track:0qvCuc6fifzBd1wwsXedeC',
     'spotify:track:1gTpngtG7wJGnGmlgKZ0ew',
     'spotify:track:4ARhdB2FzpXcko8T03YVen',
     'spotify:track:6ijikBGYf0OHlVIvm8lept',
     'spotify:track:0G8eOTTegmNQwuKWUqxye9',
     'spotify:track:66PmO1K6RXjj6ouXzMeodH',
     'spotify:track:2twwV8BMerFcRZ1fSEOuF1',
     'spotify:track:30bZbp1JbPVXhidkCm3ceh',
     'spotify:track:2BYiebB5e5zuQ5BSmemJpD',
     'spotify:track:5fBYKR15HkO5xzH4s3oJpy',
     'spotify:track:0Vwfd6fxFrL3kCnZSJ9vid',
     'spotify:track:0VkSBncg56TEFPQiXwvX33',
     'spotify:track:6u5Iuglddxopg126SJfJgh',
     'spotify:track:4oy5Q9wzbg43LhlubipZIZ',
     'spotify:track:1lhWdmgKs69XbvCHQs9OXR',
     'spotify:track:0DW5anNzTO7h0OlKqFsVQ6',
     'spotify:track:4eidDTiwJWEiCrDoM2AIlY',
     'spotify:track:5rfvovWBd35hYqk6rWLIrr',
     'spotify:track:0wAInqeoqKnqYiKB2pYHNT',
     'spotify:track:70RPjUR5l0jmBQndfNXP0z',
     'spotify:track:5AOcHpXfjKpHK7sDOC2Foy',
     'spotify:track:0q8nQ0H4ad4KYcZdrTZPux',
     'spotify:track:6UdFBqkgJwKPdO0Gcdg7kK',
     'spotify:track:6s0NHplywwr1IjnQpUpWJk',
     'spotify:track:2GqvbLpOPU73AYu13XPEgs',
     'spotify:track:2olSJ44gEfU3t02ZfhqCee',
     'spotify:track:0K6yUnIKNsFtfIpTgGtcHm',
     'spotify:track:4uLU6hMCjMI75M1A2tKUQC',
     'spotify:track:68ZD7M5tOBBM0N5XWRECoD',
     'spotify:track:6iNJ8Zdt3Kb2E7JuvTj6B5',
     'spotify:track:1AkTW13ysu0AJrwuM6UY0I',
     'spotify:track:0ODwXxkMyxS1a8T08foJtc',
     'spotify:track:4STCTQ1h0VuWfvDyhGOxkv',
     'spotify:track:0oXwUeFAE6IR2lYhaTpxRT',
     'spotify:track:5DuTNKFEjJIySAyJH1yNDU',
     'spotify:track:5AUWrwBm4cUp71jJhXHctA',
     'spotify:track:1jqB1YzZaDrxYKaFqTDLUe',
     'spotify:track:7jxWVuVdosa6eGlHSZWXQJ',
     'spotify:track:0DdpxWfVvUGgkJv5536tiF',
     'spotify:track:61jZlxHGgf2qM3Ehe0v6e3',
     'spotify:track:48IaSV3rxpZtD0DuSOOcli',
     'spotify:track:5efvxYn0J1q8iuIZBqpDD7',
     'spotify:track:3kKVqFF4pv4EXeQe428zl2',
     'spotify:track:5l9c6bJmzvftumhz4TMPgk',
     'spotify:track:4V7sFJGYLOQYyJPxQ3CPNP',
     'spotify:track:6vITFXjXN3i1VwWI1iv3fc',
     'spotify:track:6HKUskrFUQdUoiVr3dO6yj',
     'spotify:track:6CDaYzCjahDKqFAIslpveh',
     'spotify:track:54KFQB6N4pn926IUUYZGzK',
     'spotify:track:6D0b04NJIKfEMg040WioJQ',
     'spotify:track:2obblQ6tcePeOEVJV6nEGD',
     'spotify:track:1SayqEg8HKK2IeIEWjdYxY',
     'spotify:track:498YWgZPJWIA4lphXtCNma',
     'spotify:track:23nbDkpZ8bfquxFejACxL1',
     'spotify:track:4DyfJFTQb27adTDdhFeSgD',
     'spotify:track:3i8zsYoNVBR70hhGaZUbxK',
     'spotify:track:4qVW48hAXsfcSqTsbQr89Q',
     'spotify:track:6R0GRYk2vs2XuBVemYK5YZ',
     'spotify:track:2lOprPuB4ekjSi9jtxTUxj',
     'spotify:track:7ih9bLu9DgdO3LZ5dpunz9',
     'spotify:track:0Yp73Qo0CoR2P9kceNC46y',
     'spotify:track:1CoOHJAHtKEDnUBrp3nKAB',
     'spotify:track:0Nw7rj504Nw4erdXwaSOY5',
     'spotify:track:7usbPC0r2Scsv768oP5Uma',
     'spotify:track:6JLcz9UGiVxAmEZXlCucn5',
     'spotify:track:3xKTpGCsafXzV4muM1Hpl3',
     'spotify:track:02DaqClSJTt95OvsiroP5j',
     'spotify:track:0zU0rJoZ1qW7dBlJpM50Xm',
     'spotify:track:6TvAYNcu1Yey6oj0awxsFj',
     'spotify:track:0EL7gG7aGsBYcKWmsBvm0G',
     'spotify:track:3pGnvyd0UBaFKF9PYM2ULM',
     'spotify:track:6vfrxrPw6G2W7h6IDQdJ8n',
     'spotify:track:6TsE30wjcOmuQRheHdtaAF',
     'spotify:track:7cOKuMZ1zn36nELzNTnee9',
     'spotify:track:2TbQOKDTGrg3ppGkO3gltX',
     'spotify:track:5dZlQv1f1euEtwgKmiHZGs',
     'spotify:track:1q74TesvRCIo5RvJM5B84F',
     'spotify:track:20s34XSPIiYMGSFDRSs24t',
     'spotify:track:6EpRaXYhGOB3fj4V2uDkMJ',
     'spotify:track:36Cv84a2qCZarCdtTcMJnj',
     'spotify:track:10hkfuMIpEbTuHBTbfxlDv',
     'spotify:track:2BaXRCVgn621xHOGoFSuW5',
     'spotify:track:6yqubZF4LsME7BEHvT6kEG',
     'spotify:track:6PUJEckAKg4Mp47VFZxdpJ',
     'spotify:track:4sjFxvB5yYqJQNKx1AV6bk',
     'spotify:track:2mobr1UlKjhxDTOVqng3jw',
     'spotify:track:2jS5v72rq6sZ1uwfyd2Dxg',
     'spotify:track:1mN4jJXTVcVGhaQ2fhW9ka',
     'spotify:track:0ydi4AWyWjhR0NhF3T9lXD',
     'spotify:track:2H3BNi4FyJqjpbTv8qfTtI',
     'spotify:track:7DT8GwyRKluJhnl0BEOUA2',
     'spotify:track:1rKznc9yqyCO6b7Cdy94wG',
     'spotify:track:6GQZ5WNHhqs6b0BD0lUK96',
     'spotify:track:2Xrf39KgA7Rnr3JEcZ5LPm',
     'spotify:track:1DKhNLbprRP2CiK8jxEAOC',
     'spotify:track:7j1JdDgBADUiQLKlgxLaSI',
     'spotify:track:3ONMBfq0htubv1DjpI5b8A',
     'spotify:track:6UCDKscr5W8zSs06GTFcqX',
     'spotify:track:7ijc4vv1XTe7HRRY9ScmPD',
     'spotify:track:2V9JAFdZqOyt3nRNVWcZEJ',
     'spotify:track:47AZCUpitBMJt6Smj9Tww3',
     'spotify:track:6niggr2WDookeL2nBezZQL',
     'spotify:track:5cdxAWuRElZp7NxVAkeheW',
     'spotify:track:3lkxMjl1DE627kxCM8l6cN',
     'spotify:track:3JtmRIkVK95rmf4kWKA3ON',
     'spotify:track:3NZerG5aPauXkTKJrSfbco',
     'spotify:track:6mORGLOz79w6VsCRLWYYuK',
     'spotify:track:5xioIP2HexKl3QsI8JDlG8',
     'spotify:track:75dL1cqk3oqV1QP3NNaOdv',
     'spotify:track:3cbTV3IZZvSBYVcl0xuZbY',
     'spotify:track:6dEs3CH2goHCTR6XCTctVd',
     'spotify:track:1iUoWD9qE93GyoT80O5IKt',
     'spotify:track:5H6F1Jjq4IF8cYXTCcrq41',
     'spotify:track:5lZAzpl6XoswhDz7BukTta',
     'spotify:track:0uVyZywUNOp6S0dU5r8TS8',
     'spotify:track:0rEqoKxL9HGRRvtsQygeZn',
     'spotify:track:348jCCtlWzPsHVrYPV5oDc',
     'spotify:track:5UbBcnZXo89yBRsNzmZVxM',
     'spotify:track:54DH9HPiEDLZpEg0TjAiqz',
     'spotify:track:6Z8R6UsFuGXGtiIxiD8ISb',
     'spotify:track:1Je1IMUlBXcx1Fz0WE7oPT',
     'spotify:track:3yVXZm1flshiCRpxWQjUSK',
     'spotify:track:11AuKP7AVvmhf1gmM9Ew88',
     'spotify:track:63KYX2G5ZZTWCFflwSIgCD',
     'spotify:track:2qC1sUo8xxRRqYsaYEdDuZ',
     'spotify:track:1OWVMFheLHbjIBEX2Lz2KS',
     'spotify:track:23Jm3lAqydJirDzfCNct5o',
     'spotify:track:3Q9t1A12iUemHTAWnH7PjD',
     'spotify:track:24nRdDUUIdM2mv1YdwMdu6',
     'spotify:track:2G1YqEwL7X1DyvkGuFqMzV',
     'spotify:track:61oDWluoCJ2FowqSEEvMmq',
     'spotify:track:4BZufKgQKJNUEd4NNYHc63',
     'spotify:track:3MEHpAw1EChQaoZTCkuX3a',
     'spotify:track:01dPxcBaWnKbIRbgdVESs9',
     'spotify:track:05ApEAT889haImO4kMB6Z1',
     'spotify:track:0PM9goJ7ZaLpq5wR16LZlp',
     'spotify:track:27PmvZoffODNFW2p7ehZTQ',
     'spotify:track:2E2tfz55diBhRxmursGiUl',
     'spotify:track:0y1QJc3SJVPKJ1OvFmFqe6',
     'spotify:track:1FhbZvzP1zGhIEgtnmX7QN',
     'spotify:track:1oJaumhe1rUBOgX0k0z0eg',
     'spotify:track:7zBPzAjKAqQpcv8F8GCq5s',
     'spotify:track:3eBkt7BdfKqA87MxwFBWRG',
     'spotify:track:2dEVdJTq79QElGsZgx5rFP',
     'spotify:track:20RHP0KD0gDz7xzmzZCGBo',
     'spotify:track:4lgqc2BTURR2zY1P8J0BjP',
     'spotify:track:2ZXsvL9DO2MPv43Ay1IxgR',
     'spotify:track:7gHcMwqOmD1aEUfEjsz0MO',
     'spotify:track:6Yk8ceRQHJJCkcEntNIkzi',
     'spotify:track:0RN5fZ3SVyT0VhltQxNQx4',
     'spotify:track:4T6p9mFEP9J1HbQWfdIP6F',
     'spotify:track:3XabgBQYC7H80agKcAq83Y',
     'spotify:track:2hhHwY2rzWLeFenIg3e6o0',
     'spotify:track:3FUJGbUvwM8IooDXaY8mN1',
     'spotify:track:2WMRd3xAb9FwXopCRNWDq1',
     'spotify:track:0gljI0CtjpdZK6ecidfxto',
     'spotify:track:3uhvGiBZWL2sot0pH0qRsR',
     'spotify:track:6b6bYwJGyVMrRshcJ1WHru',
     'spotify:track:6uQKuonTU8VKBz5SHZuQXD',
     'spotify:track:7wMq5n8mYSKlQIGECKUgTX',
     'spotify:track:5hbNSo9Ckl7ku8664sn0Jj',
     'spotify:track:4q1LP4YcHOIUy8XSqpR8HH',
     'spotify:track:2pbWkjtGtjkzBdZ95GFINm',
     'spotify:track:4gvea7UlDkAvsJBPZAd4oB',
     'spotify:track:6m0qBDIhzICOwWMPZdgyVK',
     'spotify:track:41CUuaX52fZjRzzCK0rkkh',
     'spotify:track:4ya82vEkIk1HJpuPDhESOC',
     'spotify:track:0G3fbPbE1vGeABDEZF0jeG',
     'spotify:track:0sXvAOmXgjR2QUqLK1MltU',
     'spotify:track:5sFDReWLrZHLFZFjHsjUTS',
     'spotify:track:7rlCeTnjn0plPZkVAcctPZ',
     'spotify:track:3sBNaoeB8nQGtognBs5ycd',
     'spotify:track:0nKxQeKar9oFerIGJ8H3nc',
     'spotify:track:1z15fhSgN6U2k4gqA1Zu4j',
     'spotify:track:7jokW7mTAhBIuXW43OQlQR',
     'spotify:track:0KB8A2jnZKT6aXvOzhKlCo',
     'spotify:track:31G6mhkP3crrFhLEZUZOhW',
     'spotify:track:6vRp1EGkh1SE7uGNhbqVjT',
     'spotify:track:2GUPyVJIFf9jMVRjhThmnY',
     'spotify:track:4Lora6205JbkK6BJlttlRH',
     'spotify:track:3k9upsOz6gyeOEcUX9fkmT',
     'spotify:track:6MdqqkQ8sSC0WB4i8PyRuQ',
     'spotify:track:1RjCsqiatsrQwQvqjecr30',
     'spotify:track:71kZP3u1h27zyjfULjSxPT',
     'spotify:track:00SlXYapXP5KuDarLc2hUJ',
     'spotify:track:0bAM9qivrntXnHyklRRx39',
     'spotify:track:2BPfKiV9U0CR1dpUgeUwuH',
     'spotify:track:2mLvvy1t4MgseCIevIf9yS',
     'spotify:track:7n5m8nDAnyXo81tr4B3Bcw',
     'spotify:track:01a0J96fRD91VnjQQUCqMK',
     'spotify:track:71dfpbSERvHqZKAGQBeBRk',
     'spotify:track:0YuYjJAVSCC3RViA8oEZXF',
     'spotify:track:1yy2DlSDtEt90d54rPDPXz',
     'spotify:track:0IxGgqjkjVtC9za87YRGtK',
     'spotify:track:3VAeTjREoKPY1exOXR4oBm',
     'spotify:track:7ptQpw6gUibtO1mPufc2FD',
     'spotify:track:15EPc80XuFrb2LmOzGjuRg',
     'spotify:track:1280ebYtTct0ytDEZdrcvQ',
     'spotify:track:5L25WIqnruhVYln7jxAJ8p',
     'spotify:track:19gEmPjfqSZT0ulDRfjl0m',
     'spotify:track:3b00LSFIRqnHvkoDEs5fkg',
     'spotify:track:3xjseYFU26DIH1ikZN263F',
     'spotify:track:4QUu6TJFb1kYxoBRMSKNWI',
     'spotify:track:1JqVM7aB2AwafhGHRABPAA',
     'spotify:track:0cJLYpRTqODzv9SiQukE4Z',
     'spotify:track:1pvGWSvIXr8PTk8nC4SnXK',
     'spotify:track:6nN9m73dugjVC2MCNpnq5o',
     'spotify:track:5wpDupdKxD4aKNV8kbtdYt',
     'spotify:track:3UjJP4ludb74a29P5EHEIo',
     'spotify:track:2lmKQwpiWVDYoBvc0SEMhe',
     'spotify:track:1fnULsZuORnAgCFFbM8nTZ',
     'spotify:track:3epn3iuLX3oNzGOAA1144S',
     'spotify:track:37JPdGgYcQAJSElj5boJx8',
     'spotify:track:00gwlKTiWvu6xqvsWy7ehA',
     'spotify:track:5yc59J3MR3tVDPTOgwgRI5',
     'spotify:track:6sghEq6gM4Ugadwa12H7Sa',
     'spotify:track:5LgYy64uprlaC3fb8ysnte',
     'spotify:track:30XzWDBISN78wuaIq0isX7',
     'spotify:track:4zkuXwGFnAsdC6oROpTKX0',
     'spotify:track:7LD5Kxk4Ut16nvic7liiHs',
     'spotify:track:0RMr1YqH6Mv6HeklKsl76e',
     'spotify:track:1pNlZQeoPnlxqf1Mjgm0H2',
     'spotify:track:3XJJP46XhBhNWyVJ7DjZtO',
     'spotify:track:5Y6Q2X9TOKOcHD3I3Gevo8',
     'spotify:track:03egwBfmIRrfZtGCBhj5kg',
     'spotify:track:0CokSRCu5hZgPxcZBaEzVE',
     'spotify:track:3HU4vFJPelZfj0xyJDVALk',
     'spotify:track:0KQ1LhU7vGiXqn7eAw1nfl',
     'spotify:track:1KzW2k1dNh9nJrK6WhneTW',
     'spotify:track:0jSMveIWvnhDIvzqN74Uc7',
     'spotify:track:70adgkFUakt1DgxqwTMC6X',
     'spotify:track:6yIHGmQLJxWAUZ1ZkENemN',
     'spotify:track:7oufCpJK1BHeZ3QfBjydBB',
     'spotify:track:5Crm1pbONlPuh9MzVg8usZ',
     'spotify:track:0V8jGgK39sLsj2yAHHPigU',
     'spotify:track:4JFM7KpVxgPXargA4rzB60',
     'spotify:track:7AjfklMN4WpQYz5FkT4E66',
     'spotify:track:4SGBuq37Ol4HJr7pQqFMKa',
     'spotify:track:493S4t7eq13ehGKl5g9WS9',
     'spotify:track:6P2Lh7h0yzo8gbI2cIBtIp',
     'spotify:track:751wKDM4y5zurzhSxcUxqP',
     'spotify:track:6h9xi8i9zVOXk5FqGqcBNH',
     'spotify:track:0tICYNayWWhH9GPeFrfjfD',
     'spotify:track:63BokRfXSQhEU6Qi2dSJpZ',
     'spotify:track:7cVmKBwzPsh4Fmb6SplfEm',
     'spotify:track:2XTTOhk57lti1sEuRgmmVS',
     'spotify:track:3BSm4qArTl6tLgTx92LSYt',
     'spotify:track:21BrE3qn6z1S3KNA4d8uPK',
     'spotify:track:4X4NrHp5VpibgirzuImxXd',
     'spotify:track:5z6xHjCZr7a7AIcy8sPBKy',
     'spotify:track:5RsUlxLto4NZbhJpqJbHfN',
     'spotify:track:0kMxybaVSjw5oXbHG9sDdc',
     'spotify:track:4UrlusvpRQab5AWb1SqEjR',
     'spotify:track:1mMLMZYXkMueg65jRRWG1l',
     'spotify:track:4SXcG6Ti32myNw9GJ9qeDt',
     'spotify:track:0weAUscowxeqDtpCgtbpgp',
     'spotify:track:3gZUflBBfgS3QiTSTg0hk0',
     'spotify:track:2bRTv94ezSCAYb04N7siLH',
     'spotify:track:0F5DFgLAu53jPN8ElmZssr',
     'spotify:track:1vNn7rVQT6UtEW1NGH53fT',
     'spotify:track:6ROH6PSoPDUDeYzE98UL9T',
     'spotify:track:0k6HUzaRHpQ3eEWr1C7Esh',
     'spotify:track:40yJGQyEaBbIkXpwMFkXip',
     'spotify:track:1TFui640dnG5YInNTqY4SX',
     'spotify:track:0TnN3SbTgg9vJePYjw4QHx',
     'spotify:track:7osBjxxoPSCceUMdkyFh9O',
     'spotify:track:39aRmixB9qNtCU2t8BmsC1',
     'spotify:track:7FuRjlwyTY9uTAUgGpZtJU',
     'spotify:track:1JURww012QnWAw0zZXi6Aa',
     'spotify:track:7wsOAPS2qrNmJp0UJjMwJv',
     'spotify:track:1XHFob24QklIXtLRopKirJ',
     'spotify:track:4gAgdhTIx6T76baPfbXHQX',
     'spotify:track:0W0rNPWbtsSLe48UZUwqf4',
     'spotify:track:2ghy3erwyL3ZvQthH7iXhS',
     'spotify:track:0uMn8WKu3qtQLaUyal1bsz',
     'spotify:track:17OrgPBqhjPkYo9RKMBl0D',
     'spotify:track:4W0m2V6Lc2bSQRl7xZiGx1',
     'spotify:track:6mb6lVLNrcUgLnEN8QnDJd',
     'spotify:track:0kEQwPz9SrMN8E5iL9cxQL',
     'spotify:track:0W7AbEauB7cP4pidLclApe',
     'spotify:track:6y2DHyCYf6azhUfXmnuH6w',
     'spotify:track:5WsE374LpBomAkCRSOcjWo',
     'spotify:track:51FpzuGkRYXFgsE2zXt9av',
     'spotify:track:5ISLPbBXYc9mpgxyAuXsls',
     'spotify:track:2LdaAgX3r9WiyuOJRoN5m2',
     'spotify:track:6BEaCD75Zwlg7B63nATEli',
     'spotify:track:6VW0KDtZA6AeDoOMIxMpNi',
     'spotify:track:2RPbEp0DyBVlkRvvYKopO7',
     'spotify:track:4OmO3r5F1pWwxExUQhP2xN',
     'spotify:track:7eFRKuSuznmVqA8nx4PPAQ',
     'spotify:track:7kGHK6l1CKog8aJNodtKcc',
     'spotify:track:6ekV6MGnPTuCOnjB4VcWGc',
     'spotify:track:2boJnT3S2aSBagFEUTXrfx',
     'spotify:track:1rLl5GAkjPXVbG2B8MrZAi',
     'spotify:track:57VjUdfXzNsDVCaKJv2d7I',
     'spotify:track:1u9O8H6eSMx5x1zNOn41WL',
     'spotify:track:3RwbqrHZwHg3hpe6sOxMpE',
     'spotify:track:37f4ITSlgPX81ad2EvmVQr',
     'spotify:track:6MDijuuArPJv1vbp7K1x3f',
     'spotify:track:6A4Jc8npNo79BOgsrPptLA',
     'spotify:track:51c94ac31swyDQj9B3Lzs3',
     'spotify:track:4kgd0pyMhITxnnRbalpCNi',
     'spotify:track:2uA9UIwIh80JVNblihS6gt',
     'spotify:track:63SF10lPoWA71bDYYzxfUs',
     'spotify:track:5hKQZ1Ek9ZPc2c6LSBIJN1',
     'spotify:track:22eADXu8DfOAUEDw4vU8qy',
     'spotify:track:4rr19p6NPfg8oUazZQnkS8',
     'spotify:track:2WEAKylXBPr9PJNANBSTDG',
     'spotify:track:7MtIfFyKeTnLp8ovMSORNu',
     'spotify:track:0Yqkp4ScyWSKTlm7hpnDQN',
     'spotify:track:05go6bBS3fbZbXC2p8xTfW',
     'spotify:track:7vnyJvpBh3fJb3DgEVG9Qo',
     'spotify:track:2FjKa1YG4rHkboNHsWO3iB',
     'spotify:track:08Z7Ve3H5p850qQfG9N3Of',
     'spotify:track:2xwsf9FuFINP1X4FTsqZ7Q',
     'spotify:track:6kig1UFggPUyZBCvXD3Wod',
     'spotify:track:5YX2R55h76mamgXwsvBRlH',
     'spotify:track:1pETXdNqwtgic1p4SumvRD',
     'spotify:track:57JZzPUi3vR9b9hRRtdISg',
     'spotify:track:3uMB82o0qa7erhiZBW9KQC',
     'spotify:track:4nOKwZf1XRw2gI4FGAGhXf',
     'spotify:track:3U1TuSqHIubBA10cVP7Sk6',
     'spotify:track:3xhXKRGahWzcXF8rD5gUvd',
     'spotify:track:2NORVPq8BWFa5VbQOAawz0',
     'spotify:track:1HxoNjuKUQbxDy1vqevNhu',
     'spotify:track:7yCqehT9dKACTFy7YugP0J',
     'spotify:track:0DBIL8arX0Zo6eAuxNIpik',
     'spotify:track:64o2ZoFrCnLN8rCRIP0K1I',
     'spotify:track:5vMAKJ78vhNtvbIKz4yeIY',
     'spotify:track:6zMUIb4uce1CzpbjR3vMdN',
     'spotify:track:3Ik70XpNvyJ3wV3dxPw90w',
     'spotify:track:0XoGin3sawtB2HmME0Ikn3',
     'spotify:track:0XOUTAbbOt3DJyaF1934yz',
     'spotify:track:5aA0BanaTWun8BIAAFCcxr',
     'spotify:track:65ES1qwOB577ZnTkizMXJJ',
     'spotify:track:2kpziA4mHuM7Na6La4upg1',
     'spotify:track:7025POEXvQLugcpy6cNVSq',
     'spotify:track:4nBZIQ14fOYMxJvgbvHQpJ',
     'spotify:track:2kKL5kk4On8YRSKWDgXWMX',
     'spotify:track:7FesdPPnPPE70f4Xyjv71H',
     'spotify:track:53jMQBVML1vqNhSGybHYbm',
     'spotify:track:1uSuUREEc2TBpqW64mRa4A',
     'spotify:track:17S6bmbQdsnDQUKtgexI5b',
     'spotify:track:3yZfH82ijiYuMBpYcDJo5I',
     'spotify:track:296mmTJOJ904FwHQsSBdDr',
     'spotify:track:6VhlABJh5uaZOpyyi5wute',
     'spotify:track:3tcpDYxRmUe4O3ylYXl1xM',
     'spotify:track:6XKm1z5lYIq486iWMLnSFY',
     'spotify:track:38D70EX1pTiJPrK4YVAtjG',
     'spotify:track:0fZq48okuWkpAgjsWogAJ4',
     'spotify:track:3AH9lQx7COmyQKq5SqJRrX',
     'spotify:track:1oTHteQbmJw15rPxPVXUTv',
     'spotify:track:49rnuaQOpoTeKe0PA5nKdo',
     'spotify:track:7mMlbJlXXo2mRtQ4R9sIzD',
     'spotify:track:7uzudGwu8EG5deuFD7EEJm',
     'spotify:track:2CPqh63wRVscbceKcPxwvv',
     'spotify:track:3TW48DvQ7ChwY1Yy1tkMaP',
     'spotify:track:6xxkyxprEd4B9a28yrhsyR',
     'spotify:track:07lZt2VQlkNtNTyK1qGLw0',
     'spotify:track:1xcDKZqyEg1dIgsidluiFP',
     'spotify:track:0DAmSYQW9kq9gQNDI002KP',
     'spotify:track:0z9hbAY5d0RhmvZr3DWMPK',
     'spotify:track:6qx90ZvCLa8s0UPm86DbOb',
     'spotify:track:6fXzclKMWcYFIvRPREufPf',
     'spotify:track:1LzNfuep1bnAUR9skqdHCK',
     'spotify:track:04j2YvoGqnRSTDyzRdZkqq',
     'spotify:track:61KHfpOOqUgSWpzfpufkzs',
     'spotify:track:2SZDu4esDLUISRnpYQE17b',
     'spotify:track:7nEkBczicAhAPEaAT3UbeY',
     'spotify:track:10OjtySLPWbVHJRB71MjJi',
     'spotify:track:3pfXxHoydFRfD7IBGJTQAN',
     'spotify:track:2ctM11eovXsKVkiQTaMx4t',
     'spotify:track:5NAsayJ95IyU7B9zpPSb4P',
     'spotify:track:51oVwsllGkGySCLW6inIXE',
     'spotify:track:3zjjzKg16tczCMwckGKGuH',
     'spotify:track:19BkO3i2H6TwBIiPCCdR4f',
     'spotify:track:4RkFfhPe52X9sv5iCl3ixA',
     'spotify:track:6VI93a0A7kqPK7vXPf50nL',
     'spotify:track:6U4VqEHy4n5VeiH4pQPL24',
     'spotify:track:3XvIkeomrbYnwIzLUFiYHG',
     'spotify:track:5dsGyRTXP370sgS6Cz13Vh',
     'spotify:track:3Ji3MhxkAHYs8Byc3O1Jgk',
     'spotify:track:50fCm9Wuerl1Ram0FUDEaL',
     'spotify:track:4OXqW9GmQlRgJZR519ebBZ',
     'spotify:track:1Z5L1sgdPUPfcuxsfaYzcB',
     'spotify:track:20Bq3bQWFKZA8NOodSSSfG',
     'spotify:track:7nYvUtkQMx1v80S2FH2s9J',
     'spotify:track:4eLYVYZVbaBU0nYeuWbHdh',
     'spotify:track:1x7QWWVpQdoiOGDRWuSK5l',
     'spotify:track:4PWY72AubTjoZrohQt0pWn',
     'spotify:track:2xqjlxsJpuRwNnq5iz9sGX',
     'spotify:track:376KnY4TrgBITxjlnbnmIy',
     'spotify:track:3mT1AONeTJDi1k8vH8pA2L',
     'spotify:track:0IbNasZaAuAIsA5go3TA9R',
     'spotify:track:3mogmakkKiKWOB0tVj1X9i',
     'spotify:track:2c5Isyd07hWsl7AQia2Dig',
     'spotify:track:1U3YVpWhRLQ8MLk7SK9PtZ',
     'spotify:track:1aa5vynK6KH38TANV1Pac0',
     'spotify:track:5iKoarDSV0EA1JN10Bljr5',
     'spotify:track:1dadMFSGIJATXdcNqIUTOA',
     'spotify:track:5Axpb85IKY90OUkFadiSTM',
     'spotify:track:1DThYRRQ0Hwtn1JeJNAqyK',
     'spotify:track:71x6TqO4mB9IvwCdxdT9iA',
     'spotify:track:5DOYik1z3Of1wAFfY3dYbC',
     'spotify:track:67RoNS4g0UH1HWz96fNjAu',
     'spotify:track:5Tp97LcL45G82uC6vaLvt5',
     'spotify:track:0LBtQiEVfP4ysLQ43Do8uN',
     'spotify:track:5WLpGF9jTjcdaN9idvUdFN',
     'spotify:track:7EXr7Wx6WXdr4vLNGc48xw',
     'spotify:track:0D4ZDFhwclf2FxZb5wm3qm',
     'spotify:track:2iUmqdfGZcHIhS3b9E9EWq',
     'spotify:track:49dFv4gH1SeY90FySDOwCE',
     'spotify:track:7HLTfpgbqC85BayqViMHmU',
     'spotify:track:6xANFc4ajkfCOCivvrtD7U',
     'spotify:track:516V4vS25xnGdVgkBWO6Wf',
     'spotify:track:1o9qSSbiqbQqgtFlCFixYz',
     'spotify:track:5rF35meCdTHjDL92rc5q4m',
     'spotify:track:359krpyCKcFF8SFvqWES9L',
     'spotify:track:362zcsyXMLbL7PNLhOovvm',
     'spotify:track:3PEgB3fkiojxms35ntsTgs',
     'spotify:track:3kFLioKmQO7tnGxb8OZ0Sy',
     'spotify:track:46zKgD8f2UecI18HLeUABs',
     'spotify:track:6ALzPzdLTCGceKBwwb5lfi',
     'spotify:track:3B7i9OKRRmIsSBHEbJz58Y',
     'spotify:track:5wTM2Bm8phDwHAuOsfBwhU',
     'spotify:track:5SqikUf4UzapxE4ApV5Sb6',
     'spotify:track:5fsAuyAlYenYBV07603Iea',
     'spotify:track:6TT0FMoNtq9Dn78Rq0Yldo',
     'spotify:track:6qMXubogFdMrvVMJwqATzd',
     'spotify:track:0JCS7q2sxbydawkUCVIuhK',
     ...]



There you go!
